@@ -1,6 +1,10 @@
 /* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 4 -*-
  * vim: set ts=8 sw=4 et tw=99:
  */
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
+
 
 #include "tests.h"
 
@@ -8,7 +12,8 @@ BEGIN_TEST(testDeepFreeze_bug535703)
 {
     jsval v;
     EVAL("var x = {}; x;", &v);
-    CHECK(JS_DeepFreezeObject(cx, JSVAL_TO_OBJECT(v)));  // don't crash
+    JS::RootedObject obj(cx, JSVAL_TO_OBJECT(v));
+    CHECK(JS_DeepFreezeObject(cx, obj));  // don't crash
     EVAL("Object.isFrozen(x)", &v);
     CHECK_SAME(v, JSVAL_TRUE);
     return true;
@@ -19,12 +24,13 @@ BEGIN_TEST(testDeepFreeze_deep)
 {
     jsval a, o;
     EXEC("var a = {}, o = a;\n"
-         "for (var i = 0; i < 10000; i++)\n"
+         "for (var i = 0; i < 5000; i++)\n"
          "    a = {x: a, y: a};\n");
     EVAL("a", &a);
     EVAL("o", &o);
 
-    CHECK(JS_DeepFreezeObject(cx, JSVAL_TO_OBJECT(a)));
+    JS::RootedObject aobj(cx, JSVAL_TO_OBJECT(a));
+    CHECK(JS_DeepFreezeObject(cx, aobj));
 
     jsval b;
     EVAL("Object.isFrozen(a)", &b);
@@ -42,7 +48,8 @@ BEGIN_TEST(testDeepFreeze_loop)
     EVAL("x", &x);
     EVAL("y", &y);
 
-    CHECK(JS_DeepFreezeObject(cx, JSVAL_TO_OBJECT(x)));
+    JS::RootedObject xobj(cx, JSVAL_TO_OBJECT(x));
+    CHECK(JS_DeepFreezeObject(cx, xobj));
 
     jsval b;
     EVAL("Object.isFrozen(x)", &b);
